@@ -1,5 +1,5 @@
 package QBit::QueryData;
-$QBit::QueryData::VERSION = '0.004';
+$QBit::QueryData::VERSION = '0.005';
 use qbit;
 
 use base qw(QBit::Class);
@@ -211,7 +211,7 @@ sub get_all {
 
     my @result = ();
 
-    my @fields = @{$self->get_fields()};
+    my @fields = @{$self->get_fields() // []};
     if ($self->{'__DISTINCT__'}) {
         my %uniq = ();
 
